Configuration Examples
======================

Basic Replacement
-----------------
Use this configuration to swap fonts when you have a clean 1-to-1 mapping.

.. literalinclude:: ../examples/simple_replace.json
   :language: json
   :caption: examples/simple_replace.json

Advanced Mapping
----------------
Use this configuration if you need to fix broken character encodings or allow wider scaling limits.

.. literalinclude:: ../examples/advanced_mapping.json
   :language: json
   :caption: examples/advanced_mapping.json